.. _lab_meetings:

Lab Meetings on Air
===================

.. attention::
    This is copied verbatim from the old IPython wiki and is currently under development. Much of the information in this part of the development guide is out of date.

Academic labs have long had the tradition of the weekly lab meeting,
where all topics of interest to the lab are discussed. IPython has
strong roots in academia, but it is also an open source project that
needs to engage an active international community. So while our goal
with IPython is not to publish the next paper, we've been thinking about
the value these regular discussions bring to how teams work on sustained
efforts involving difficult problems, and wanted to bring that bit of
academic practice into the open source workflow. So we have decided to
conduct weekly "lab meetings" for IPython, that will be held publicly
using a Google Hangout on Air.

Logistics
---------

We are trying to keep things simple and with a minimum of new moving
parts:

-  Meetings happen on Tuesdays at 10am California time (i.e. UTC-8 or -7
   depending on the time of year).
-  We broadcast the meeting as it happens via G+ and leave the public
   YouTube link afterwards.
-  During the meeting, all chat that needs to happen by typing can be
   done on our `Gitter chat
   room <https://gitter.im/ipython/ipython>`__.
-  We keep a running document with `minutes of the meeting on
   HackPad <https://ipython.hackpad.com/>`__ where we summarize main
   points. (`2015 part 1 <https://ipython.hackpad.com/3YJG5lv2Hws>`__)

We welcome and encourage help from others in updating these minutes
during the meeting, but we'll make no major effort in ensuring that they
are a detailed and accurate record of the whole discussion. We simply
don't have the time for that.

Prior meetings
--------------

You can find a list of the videos on the `ipythondev YouTube user
page <https://www.youtube.com/user/ipythondev>`__.
